@@ -15,6 +15,19 @@ sub new {
 
     $self->_init(%p);
 
+    my %defaults = (
+        reconnect_attempts => 1,
+        reconnect_sleep    => 0,
+    );
+
+    for (keys %defaults) {
+        if(exists $p{$_}) {
+            $self->{$_} = $p{$_};
+        } else {
+            $self->{$_} = $defaults{$_};
+        }
+    }
+
     #e.g.
     #log4j.appender.DBAppndr.params.1 = %p    
     #log4j.appender.DBAppndr.params.2 = %5.5m
@@ -119,17 +132,30 @@ sub log {
 sub query_execute {
     my($self, $sth, @qmarks) = @_;
 
-    for(1..2) {
+    for my $attempt (0..$self->{reconnect_attempts}) {
         if(! $sth->execute(@qmarks)) {
                 # Exe failed
                 # warn "Log4perl: DBI->execute failed $DBI::errstr, \n".
                 #                  "on $self->{SQL}\n@qmarks";
+                if($attempt == $self->{reconnect_attempts}) {
+                    croak "Log4perl: DBI appender failed to reconnect to database " .
+                          "after $self->{reconnect_attempts} attempt" .
+                          ($self->{reconnect_attempts} == 1 ? "" : "s");
+                }
             if(! $self->{dbh}->ping()) {
-                # Ping failed, reconnect
-                $self->{dbh} = $self->{connect}->();
+                # Ping failed, try to reconnect
+                if($attempt) {
+                    sleep($self->{reconnect_sleep}) if $self->{reconnect_sleep};
+                }
+
+                eval {
+                    #warn "Reconnecting to DB";
+                    $self->{dbh} = $self->{connect}->();
+                };
+
                 $sth = $self->create_statement($self->{SQL});
                 $self->{sth} = $sth if $self->{sth};
-                redo;
+                next;
             }
         }
         return 1;
@@ -531,6 +557,13 @@ might go stale, but if C<Log::Log4perl::Appender::DBI> tries to write
 a message and figures out that the DB connection is no longer working
 (using DBI's ping method), it will reconnect.
 
+The reconnection process can be controlled by two parameters,
+C<reconnect_attempts> and C<reconnect_sleep>. C<reconnect_attempts>
+specifies the number of reconnections attempts the DBI appender 
+performs until it gives up and dies. C<reconnect_sleep> is the
+time between reconnection attempts, measured in seconds.
+C<reconnect_attempts> defaults to 1,  C<reconnect_sleep> to 0.
+
 Alternatively, use C<Apache::DBI> or C<Apache::DBI::Cache> and read
 CHANGING DB CONNECTIONS above.
 
